#!/usr/bin/env python3
# -*- encoding: utf-8
# SPDX-License-Identifier: MIT
# Copyright (c) 2021 - 2022, Scott.McCallum@HQ.UrbaneINTER.NET

__banner__ = r""" (

                  _           _   _
                 (_)         (_) | |
                  _   _ __    _  | |_                       _ __    _   _
                 | | | '_ \  | | | __|                     | '_ \  | | | |
                 | | | | | | | | | |_                   _  | |_) | | |_| |
                 |_| |_| |_| |_|  \__|                 (_) | .__/   \__, |
  ______ ______                         ______ ______      | |       __/ |
 |______|______|                       |______|______|     |_|      |___/

)







"""  # __banner__
